/*-------------------------------------------------------------------------+
| Copyright 2018 fortiss GmbH                                              |
|                                                                          |
| Licensed under the Apache License, Version 2.0 (the "License");          |
| you may not use this file except in compliance with the License.         |
| You may obtain a copy of the License at                                  |
|                                                                          |
|    http://www.apache.org/licenses/LICENSE-2.0                            |
|                                                                          |
| Unless required by applicable law or agreed to in writing, software      |
| distributed under the License is distributed on an "AS IS" BASIS,        |
| WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. |
| See the License for the specific language governing permissions and      |
| limitations under the License.                                           |
+--------------------------------------------------------------------------*/
package org.fortiss.af3.platform.raspberry.ui.properties;

import static org.eclipse.jface.databinding.swt.SWTObservables.observeSelection;
import static org.fortiss.tooling.kernel.ui.util.ObservableUtils.observeValue;

import org.eclipse.core.databinding.observable.value.IObservableValue;
import org.eclipse.swt.SWT;
import org.eclipse.swt.widgets.Button;
import org.eclipse.swt.widgets.Composite;
import org.eclipse.ui.views.properties.tabbed.TabbedPropertySheetPage;
import org.fortiss.af3.platform.raspberry.model.brick.ActuatorDigits;
import org.fortiss.af3.platform.raspberry.model.brick.BrickPackage;
import org.fortiss.tooling.kernel.ui.extension.base.PropertySectionBase;

/** {@link PropertySectionBase} for {@link ActuatorDigits}s. */
public class ActuatorDigitsPropertySection extends PropertySectionBase {
	/** The actuator model element. */
	private ActuatorDigits actuator;
	/** The hex output button. */
	private Button hexOutputFlagButton;

	/** {@inheritDoc} */
	@Override
	public void createControls(Composite parent, TabbedPropertySheetPage tabbedPropertySheetPage) {
		super.createControls(parent, tabbedPropertySheetPage);
		hexOutputFlagButton = getWidgetFactory().createButton(composite, "", SWT.CHECK);
		createFormEntry(hexOutputFlagButton, "Coordinator Unit");
		hexOutputFlagButton.setSelection(false);
	}

	/** {@inheritDoc} */
	@Override
	protected void setSectionInput(Object input) {
		actuator = (ActuatorDigits)input;
	}

	/** {@inheritDoc} */
	@Override
	public void refresh() {
		super.refresh();
		IObservableValue modelObservable =
				observeValue(actuator, BrickPackage.Literals.ACTUATOR_DIGITS__SHOW_HEX_VALUE);
		dbc.bindValue(observeSelection(hexOutputFlagButton), modelObservable);
	}
}
