/*-------------------------------------------------------------------------+
| Copyright 2018 fortiss GmbH                                              |
|                                                                          |
| Licensed under the Apache License, Version 2.0 (the "License");          |
| you may not use this file except in compliance with the License.         |
| You may obtain a copy of the License at                                  |
|                                                                          |
|    http://www.apache.org/licenses/LICENSE-2.0                            |
|                                                                          |
| Unless required by applicable law or agreed to in writing, software      |
| distributed under the License is distributed on an "AS IS" BASIS,        |
| WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. |
| See the License for the specific language governing permissions and      |
| limitations under the License.                                           |
+--------------------------------------------------------------------------*/
package org.fortiss.af3.platform.raspberry.generator.extension.brick;

import org.fortiss.af3.component.model.OutputPort;
import org.fortiss.af3.platform.raspberry.generator.framework.IInstanceGeneratorExtension;
import org.fortiss.af3.platform.raspberry.generator.framework.IWriteableGeneratorExtension;
import org.fortiss.af3.platform.raspberry.model.brick.ActuatorDigits;

/**
 * Generator extension for {@link ActuatorDigits}s.
 * 
 * @author hoelzl
 */
public class ActuatorDigitsGeneratorExtension extends
		InstanceBrickGeneratorExtensionBase<ActuatorDigits> implements
		IWriteableGeneratorExtension, IInstanceGeneratorExtension {
	/** Constructor. */
	public ActuatorDigitsGeneratorExtension(ActuatorDigits modelElement) {
		super(modelElement);
	}

	/** {@inheritDoc} */
	@Override
	public String getHeaderFileName() {
		return "bricklet_segment_display_4x7.h";
	}

	/** {@inheritDoc} */
	@Override
	public String getInstanceVariableDeclaration() {
		StringBuilder sb = new StringBuilder();
		sb.append("static SegmentDisplay4x7 segment_display_" + getInstancePostfix() + ";\n");
		return sb.toString();
	}

	/** {@inheritDoc} */
	@Override
	public String getInstanceAuxiliaryFunctions() {
		String postfix = getInstancePostfix();
		StringBuilder sb = new StringBuilder();
		sb.append("static void set_led_display_" + postfix +
				"(SegmentDisplay4x7 *segment_display, uint16_t value, bool showHex) {\n");
		sb.append("static const uint8_t digits_" + postfix + "[] = {0x3f,0x06,0x5b,0x4f,\n");
		sb.append("                                 0x66,0x6d,0x7d,0x07,\n");
		sb.append("                                 0x7f,0x6f,0x77,0x7c,\n");
		sb.append("                                 0x39,0x5e,0x79,0x71};\n");
		sb.append("if(showHex) {\n");
		sb.append("uint8_t segments[4] = {(uint8_t) digits_" + postfix +
				"[(value >> 12) & 0x0F], (uint8_t) digits_" + postfix +
				"[(value >> 8) & 0x0F], (uint8_t) digits_" + postfix +
				"[(value >> 4) & 0x0F], (uint8_t) digits_" + postfix + "[value & 0x0F]};\n");
		sb.append("segment_display_4x7_set_segments(segment_display, segments, 5, false);\n");
		sb.append("} else {\n");
		sb.append("uint8_t segments[4] = {(uint8_t) digits_" + postfix +
				"[(value%10000)/1000], (uint8_t) digits_" + postfix +
				"[(value%1000)/100], (uint8_t) digits_" + postfix +
				"[(value%100)/10], (uint8_t) digits_" + postfix + "[value%10]};\n");
		sb.append("segment_display_4x7_set_segments(segment_display, segments, 5, false);\n");
		sb.append("}\n");
		sb.append("}\n\n");
		return sb.toString();
	}

	/** {@inheritDoc} */
	@Override
	public String getInstanceInitializationCode() {
		StringBuilder sb = new StringBuilder();
		sb.append("segment_display_4x7_create(&segment_display_" + getInstancePostfix() + ", \"" +
				modelElement.getUniqueBrickletID() + "\", &" + getConnectionVariable() + ");\n");
		return sb.toString();
	}

	/** {@inheritDoc} */
	@Override
	public String getWriteCode(OutputPort logicalSignal, String value) {
		String postfix = getInstancePostfix();
		StringBuilder sb = new StringBuilder();
		sb.append("set_led_display_" + postfix + "(&segment_display_" + postfix + ", (uint16_t)" +
				value + ", " + modelElement.isShowHexValue() + ");\n");
		return sb.toString();
	}

	/** {@inheritDoc} */
	@Override
	public String getNoValWriteCode(OutputPort logicalSignal) {
		return null;
	}

	/** {@inheritDoc} */
	@Override
	public String getInstanceTerminationCode() {
		return null;
	}
}
