/*-------------------------------------------------------------------------+
| Copyright 2018 fortiss GmbH                                              |
|                                                                          |
| Licensed under the Apache License, Version 2.0 (the "License");          |
| you may not use this file except in compliance with the License.         |
| You may obtain a copy of the License at                                  |
|                                                                          |
|    http://www.apache.org/licenses/LICENSE-2.0                            |
|                                                                          |
| Unless required by applicable law or agreed to in writing, software      |
| distributed under the License is distributed on an "AS IS" BASIS,        |
| WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. |
| See the License for the specific language governing permissions and      |
| limitations under the License.                                           |
+--------------------------------------------------------------------------*/
package org.fortiss.af3.platform.raspberry.generator.extension.rumblepad;

import org.eclipse.emf.ecore.EObject;
import org.fortiss.af3.component.model.InputPort;
import org.fortiss.af3.platform.raspberry.generator.framework.IReadableGeneratorExtension;

/**
 * Base class for executables reading rumblepad sticks and axis inputs.
 * 
 * @author hoelzl
 */
abstract class StickGeneratorExtensionBase<T extends EObject> extends
		RumblepadGeneratorExtensionBase<T> implements IReadableGeneratorExtension {
	/** Constructor. */
	public StickGeneratorExtensionBase(T modelElement) {
		super(modelElement);
	}

	/** {@inheritDoc} */
	@Override
	public final String getReadCode(InputPort logicalSignal, String targetVariable) {
		return targetVariable + " = rumblepad_get_axis_position(" + getAxisIdentifier() + ");\n";
	}

	/** {@inheritDoc} */
	@Override
	public final String getNoValReadCode(InputPort logicalSignal) {
		return null;
	}

	/** Returns the axis identifier as defined in {@code rumblepad.h}. */
	protected abstract String getAxisIdentifier();
}
